package com.dbnt.kcscbackend.admin.dashboard.service;

//import com.dbnt.kcscbackend.admin.boards.entity.TnBbsContents;
import com.dbnt.kcscbackend.admin.dashboard.repository.DashboardRepository;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@RequiredArgsConstructor
public class AdminDashboardService extends EgovAbstractServiceImpl {
    private final DashboardRepository dashboardRepository;

    public List<Object[]> selectConnMonthly() { return dashboardRepository.ConnMonthlyCount(); }

    public List<Object[]> selectErrorMonthly() { return dashboardRepository.ErrorMonthlyCount(); }

    public List<Object[]> selectDocumentMonthly() { return dashboardRepository.DocuMonthlyCount(); }

    public List<Object[]> selectComplaintMonthly() { return dashboardRepository.CompMonthlyCount(); }

    public List<Long> selectMenuMonthly() { return dashboardRepository.MenuMonthlyList(); }

    public List<Long> selectMenuDaily() { return dashboardRepository.MenuDailyList(); }

    public List<Long> selectLoginMonthly() { return dashboardRepository.LoginMonthlyList(); }

    public List<Long> selectLoginDaily() { return dashboardRepository.LoginDailyList(); }

    public List<Long> selectFileDaily() { return dashboardRepository.FileDailyList(); }

    public List<Object[]> selectQuestion() { return dashboardRepository.QuestionList(); }

    public List<Object[]> selectConnectMonthly() { return dashboardRepository.findConnMonthly(); }


}
